==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/ro.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nu s-a putut trimite mesajul către următorii utilizatori: %s",
    "Turned on maintenance mode" : "Modul mentenanță a fost activat",
    "Turned off maintenance mode" : "Modul mentenanță a fost dezactivat",
    "Updated database" : "Bază de date actualizată",
    "Updated \"%s\" to %s" : "\"%s\" a fost actualizat până la %s",
    "Repair warning: " : "Alerte reparare:",
    "Repair error: " : "Eroare de reparare:",
    "No image or file provided" : "Nu a fost furnizat vreo imagine sau fișier",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "%s password reset" : "%s resetare parola",
    "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
    "Sunday" : "Duminică",
    "Monday" : "Luni",
    "Tuesday" : "Marți",
    "Wednesday" : "Miercuri",
    "Thursday" : "Joi",
    "Friday" : "Vineri",
    "Saturday" : "Sâmbătă",
    "Sun." : "Dum.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Joi",
    "Fri." : "Vin.",
    "Sat." : "Sâm.",
    "January" : "Ianuarie",
    "February" : "Februarie",
    "March" : "Martie",
    "April" : "Aprilie",
    "May" : "Mai",
    "June" : "Iunie",
    "July" : "Iulie",
    "August" : "August",
    "September" : "Septembrie",
    "October" : "Octombrie",
    "November" : "Noiembrie",
    "December" : "Decembrie",
    "Jan." : "Ian.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Iun.",
    "Jul." : "Iul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Noi.",
    "Dec." : "Dec.",
    "Settings" : "Setări",
    "Saving..." : "Se salvează...",
    "seconds ago" : "secunde în urmă",
    "I know what I'm doing" : "Eu știu ce fac",
    "Password can not be changed. Please contact your administrator." : "Parola nu poate fi modificata. Vă rugăm să contactați administratorul dvs.",
    "No" : "Nu",
    "Yes" : "Da",
    "Choose" : "Alege",
    "Error loading file picker template: {error}" : "Eroare la încărcarea șablonului selectorului de fișiere: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Eroare la încărcarea şablonului de mesaje: {error}",
    "read-only" : "doar citire",
    "_{count} file conflict_::_{count} file conflicts_" : ["Un conflict de fişiere","{count} conflicte de fişiere","{count} conflicte de fişiere"],
    "One file conflict" : "Un conflict de fișier",
    "New Files" : "Fișiere noi",
    "Already existing files" : "Fișiere deja existente",
    "Which files do you want to keep?" : "Ce fișiere vrei să păstrezi?",
    "If you select both versions, the copied file will have a number added to its name." : "Dacă alegi ambele versiuni, fișierul copiat va avea un număr atașat la denumirea sa.",
    "Cancel" : "Anulare",
    "Continue" : "Continuă",
    "({count} selected)" : "({count} selectate)",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Shared" : "Partajat",
    "Shared with {recipients}" : "Partajat cu {recipients}",
    "Error" : "Eroare",
    "Error while sharing" : "Eroare la partajare",
    "Error while unsharing" : "Eroare la anularea partajării",
    "Error setting expiration date" : "Eroare la specificarea datei de expirare",
    "The public link will expire no later than {days} days after it is created" : "Legătura publică va expira nu mai târziu de {days} zile de la ziua creării",
    "Set expiration date" : "Specifică data expirării",
    "Expiration" : "Expira",
    "Expiration date" : "Data expirării",
    "Sending ..." : "Se expediază...",
    "Email sent" : "Mesajul a fost expediat",
    "Resharing is not allowed" : "Repartajarea nu este permisă",
    "Share link" : "Share link",
    "Link" : "Legătură",
    "Password protect" : "Protejare cu parolă",
    "Password" : "Parolă",
    "Allow editing" : "Permite editarea",
    "Email link to person" : "Expediază legătura prin poșta electronică",
    "Send" : "Expediază",
    "Shared with you and the group {group} by {owner}" : "Distribuie cu tine si grupul {group} de {owner}",
    "Shared with you by {owner}" : "Distribuie cu tine de {owner}",
    "group" : "grup",
    "notify by email" : "notifică prin email",
    "Unshare" : "Anulare partajare",
    "can share" : "se poate partaja",
    "can edit" : "poate edita",
    "create" : "creare",
    "change" : "modifică",
    "delete" : "ștergere",
    "access control" : "control acces",
    "Share" : "Partajează",
    "Warning" : "Atenție",
    "Delete" : "Șterge",
    "Rename" : "Redenumește",
    "The object type is not specified." : "Tipul obiectului nu este specificat.",
    "Enter new" : "Introducere nou",
    "Add" : "Adaugă",
    "Updating {productName} to version {version}, this may take a while." : "Se actualizează {productName} la versiunea {version}, poate dura câteva momente.",
    "Please reload the page." : "Te rugăm să reîncarci pagina.",
    "The update was successful. Redirecting you to ownCloud now." : "Actualizare reușită. Ești redirecționat către ownCloud.",
    "Personal" : "Personal",
    "Users" : "Utilizatori",
    "Apps" : "Aplicații",
    "Admin" : "Administrator",
    "Help" : "Ajutor",
    "Error loading tags" : "Eroare la încărcarea etichetelor",
    "Tag already exists" : "Eticheta deja există",
    "Access forbidden" : "Acces restricționat",
    "The share will expire on %s." : "Partajarea va expira în data de %s.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Directorul tău de date și fișiere sunt probabil accesibile de pe Internet, deoarece fișierul .htaccess nu funcționează.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Pentru informații despre cum să configurezi serverul, vezi <a href=\"%s\" target=\"_blank\">documentația</a>.",
    "Create an <strong>admin account</strong>" : "Crează un <strong>cont de administrator</strong>",
    "Username" : "Nume utilizator",
    "Storage & database" : "Stocare și baza de date",
    "Data folder" : "Director date",
    "Configure the database" : "Configurează baza de date",
    "Database user" : "Utilizatorul bazei de date",
    "Database password" : "Parola bazei de date",
    "Database name" : "Numele bazei de date",
    "Database tablespace" : "Tabela de spațiu a bazei de date",
    "Database host" : "Bază date",
    "Finish setup" : "Finalizează instalarea",
    "Log out" : "Ieșire",
    "Search" : "Căutare",
    "Log in" : "Autentificare",
    "Alternative Logins" : "Conectări alternative",
    "Use the following link to reset your password: {link}" : "Folosește următorul link pentru a reseta parola: {link}",
    "New password" : "Noua parolă",
    "New Password" : "Noua parolă",
    "Reset password" : "Resetează parola",
    "Thank you for your patience." : "Îți mulțumim pentru răbrade.",
    "Start update" : "Începe actualizarea"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/ro.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nu s-a putut trimite mesajul către următorii utilizatori: %s",
    "Turned on maintenance mode" : "Modul mentenanță a fost activat",
    "Turned off maintenance mode" : "Modul mentenanță a fost dezactivat",
    "Updated database" : "Bază de date actualizată",
    "Updated \"%s\" to %s" : "\"%s\" a fost actualizat până la %s",
    "Repair warning: " : "Alerte reparare:",
    "Repair error: " : "Eroare de reparare:",
    "No image or file provided" : "Nu a fost furnizat vreo imagine sau fișier",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "%s password reset" : "%s resetare parola",
    "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
    "Sunday" : "Duminică",
    "Monday" : "Luni",
    "Tuesday" : "Marți",
    "Wednesday" : "Miercuri",
    "Thursday" : "Joi",
    "Friday" : "Vineri",
    "Saturday" : "Sâmbătă",
    "Sun." : "Dum.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mie.",
    "Thu." : "Joi",
    "Fri." : "Vin.",
    "Sat." : "Sâm.",
    "January" : "Ianuarie",
    "February" : "Februarie",
    "March" : "Martie",
    "April" : "Aprilie",
    "May" : "Mai",
    "June" : "Iunie",
    "July" : "Iulie",
    "August" : "August",
    "September" : "Septembrie",
    "October" : "Octombrie",
    "November" : "Noiembrie",
    "December" : "Decembrie",
    "Jan." : "Ian.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Iun.",
    "Jul." : "Iul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Noi.",
    "Dec." : "Dec.",
    "Settings" : "Setări",
    "Saving..." : "Se salvează...",
    "seconds ago" : "secunde în urmă",
    "I know what I'm doing" : "Eu știu ce fac",
    "Password can not be changed. Please contact your administrator." : "Parola nu poate fi modificata. Vă rugăm să contactați administratorul dvs.",
    "No" : "Nu",
    "Yes" : "Da",
    "Choose" : "Alege",
    "Error loading file picker template: {error}" : "Eroare la încărcarea șablonului selectorului de fișiere: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Eroare la încărcarea şablonului de mesaje: {error}",
    "read-only" : "doar citire",
    "_{count} file conflict_::_{count} file conflicts_" : ["Un conflict de fişiere","{count} conflicte de fişiere","{count} conflicte de fişiere"],
    "One file conflict" : "Un conflict de fișier",
    "New Files" : "Fișiere noi",
    "Already existing files" : "Fișiere deja existente",
    "Which files do you want to keep?" : "Ce fișiere vrei să păstrezi?",
    "If you select both versions, the copied file will have a number added to its name." : "Dacă alegi ambele versiuni, fișierul copiat va avea un număr atașat la denumirea sa.",
    "Cancel" : "Anulare",
    "Continue" : "Continuă",
    "({count} selected)" : "({count} selectate)",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Shared" : "Partajat",
    "Shared with {recipients}" : "Partajat cu {recipients}",
    "Error" : "Eroare",
    "Error while sharing" : "Eroare la partajare",
    "Error while unsharing" : "Eroare la anularea partajării",
    "Error setting expiration date" : "Eroare la specificarea datei de expirare",
    "The public link will expire no later than {days} days after it is created" : "Legătura publică va expira nu mai târziu de {days} zile de la ziua creării",
    "Set expiration date" : "Specifică data expirării",
    "Expiration" : "Expira",
    "Expiration date" : "Data expirării",
    "Sending ..." : "Se expediază...",
    "Email sent" : "Mesajul a fost expediat",
    "Resharing is not allowed" : "Repartajarea nu este permisă",
    "Share link" : "Share link",
    "Link" : "Legătură",
    "Password protect" : "Protejare cu parolă",
    "Password" : "Parolă",
    "Allow editing" : "Permite editarea",
    "Email link to person" : "Expediază legătura prin poșta electronică",
    "Send" : "Expediază",
    "Shared with you and the group {group} by {owner}" : "Distribuie cu tine si grupul {group} de {owner}",
    "Shared with you by {owner}" : "Distribuie cu tine de {owner}",
    "group" : "grup",
    "notify by email" : "notifică prin email",
    "Unshare" : "Anulare partajare",
    "can share" : "se poate partaja",
    "can edit" : "poate edita",
    "create" : "creare",
    "change" : "modifică",
    "delete" : "ștergere",
    "access control" : "control acces",
    "Share" : "Partajează",
    "Warning" : "Atenție",
    "Delete" : "Șterge",
    "Rename" : "Redenumește",
    "The object type is not specified." : "Tipul obiectului nu este specificat.",
    "Enter new" : "Introducere nou",
    "Add" : "Adaugă",
    "Updating {productName} to version {version}, this may take a while." : "Se actualizează {productName} la versiunea {version}, poate dura câteva momente.",
    "Please reload the page." : "Te rugăm să reîncarci pagina.",
    "The update was successful. Redirecting you to ownCloud now." : "Actualizare reușită. Ești redirecționat către ownCloud.",
    "Personal" : "Personal",
    "Users" : "Utilizatori",
    "Apps" : "Aplicații",
    "Admin" : "Administrator",
    "Help" : "Ajutor",
    "Error loading tags" : "Eroare la încărcarea etichetelor",
    "Tag already exists" : "Eticheta deja există",
    "Access forbidden" : "Acces restricționat",
    "The share will expire on %s." : "Partajarea va expira în data de %s.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Directorul tău de date și fișiere sunt probabil accesibile de pe Internet, deoarece fișierul .htaccess nu funcționează.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Pentru informații despre cum să configurezi serverul, vezi <a href=\"%s\" target=\"_blank\">documentația</a>.",
    "Create an <strong>admin account</strong>" : "Crează un <strong>cont de administrator</strong>",
    "Username" : "Nume utilizator",
    "Storage & database" : "Stocare și baza de date",
    "Data folder" : "Director date",
    "Configure the database" : "Configurează baza de date",
    "Database user" : "Utilizatorul bazei de date",
    "Database password" : "Parola bazei de date",
    "Database name" : "Numele bazei de date",
    "Database tablespace" : "Tabela de spațiu a bazei de date",
    "Database host" : "Bază date",
    "Finish setup" : "Finalizează instalarea",
    "Log out" : "Ieșire",
    "Search" : "Căutare",
    "Log in" : "Autentificare",
    "Alternative Logins" : "Conectări alternative",
    "Use the following link to reset your password: {link}" : "Folosește următorul link pentru a reseta parola: {link}",
    "New password" : "Noua parolă",
    "New Password" : "Noua parolă",
    "Reset password" : "Resetează parola",
    "Thank you for your patience." : "Îți mulțumim pentru răbrade.",
    "Start update" : "Începe actualizarea",
    "Error loading file picker template: {error}" : "Eroare la încărcarea șablonului selectorului de fișiere: {error}",
    "Password can not be changed. Please contact your administrator." : "Parola nu poate fi modificata. Vă rugăm să contactați administratorul dvs."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
